==> kameleoon_client_flutter-2.0.0.tar.gz: example/lib/Pages/Signup/signup_page.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:kameleoon_client_flutter/kameleoon_client_flutter.dart';
import 'package:kameleoon_client_flutter_example/Components/Button.dart';
import 'package:kameleoon_client_flutter_example/Pages/Login/login_page.dart';
import 'package:flutter_svg/flutter_svg.dart';

import '../../constants.dart';
import 'package:kameleoon_client_flutter_example/Components/KTextInput.dart';

class SignupPage extends StatefulWidget {
  @override
  _SignupPage createState() => _SignupPage();
}

class _SignupPage extends State<SignupPage> {
  bool canShowSocial = false;
  Color _color = Color.fromRGBO(100, 100, 255, 1);

  @override
  void initState() {
    super.initState();
    initKameleoon();
  }

  Future<void> initKameleoon() async {
    final config = KameleoonConfiguration("clientId", "clientSecret");
    KameleoonClient client = KameleoonClientFactory.create("yjiu8jw554", config);

    client.runWhenReady(() async {
      String visitorCode = await client.getVisitorCode();
      try {
        bool? ff = await client.isFeatureActive(visitorCode, "color-feature-flag");
        if (ff == true) {
          String? color = await client.getFeatureVariable(visitorCode, "color-feature-flag", "color") as String?;
          color = "FF" + color!.toUpperCase().replaceAll("#", "");
          mainColor = Color(int.parse(color, radix: 16));
          setState(() {
            _color = mainColor;
          });
        }
      } on FeatureNotFound {
      } on NotTargeted {
      } on PlatformException {
      }

      try {
        await client.addData(visitorCode, [CustomData(30, "9876543210"), CustomData(29, "asdasda")]);
        bool showSocial = await client.isFeatureActive(visitorCode, "show-social");
        setState(() {
          canShowSocial = showSocial;
        });
      } on FeatureNotFound {
      } on NotTargeted {
        print("Not targeted");
      }
    }, () {}, Duration(seconds: 5));
  }

  @override
  Widget build(BuildContext context) {
    Size screenSize = MediaQuery.of(context).size;
    return Scaffold(
        body: Container(
            width: screenSize.width,
            height: screenSize.height,
            child: Column(
              children: <Widget>[
                Padding(
                    padding: EdgeInsets.only(bottom: 20, top: 70),
                    child: Image.asset(
                      "assets/images/logo.png",
                    )
                ),
                Text(
                  "Welcome!",
                  style: TextStyle(
                    fontWeight: FontWeight.bold,
                    fontSize: 24,
                  ),
                ),
                Padding(
                    padding: EdgeInsets.only(top: 10, bottom: 50),
                    child: Text(
                        "Sign up to create your account",
                        style: TextStyle(
                            fontWeight: FontWeight.w400,
                            fontSize: 17
                        )
                    )
                ),
                Text(
                    "Username or e-mail address",
                    textAlign: TextAlign.left,
                    style: TextStyle(
                        fontWeight: FontWeight.bold,
                        fontSize: 14
                    )
                ),
                Padding(
                    padding: EdgeInsets.only(bottom: 20, top: 5),
                    child: KTextInput(
                        suffixIcon: false,
                        icon: Icons.person,
                        hint: "Username or Email"
                    )
                ),
                Text(
                    "Password",
                    textAlign: TextAlign.left,
                    style: TextStyle(
                        fontWeight: FontWeight.bold,
                        fontSize: 14
                    )
                ),
                Padding(
                    padding: EdgeInsets.only(bottom: 30, top: 5),
                    child: KTextInput(
                        suffixIcon: true,
                        icon: Icons.lock,
                        hint: "Password"
                    )
                ),
                Button(
                  text: "Sign up",
                  bgColor: _color,
                  borderColor: _color,
                  borderWidth: 0,
                  borderStyle: BorderStyle.none,
                  textColor: Colors.white,
                ),
                Padding(
                  padding: EdgeInsets.only(top: 5),
                  child: Button(
                    text: "Already have an Account? Sign in",
                    bgColor: Colors.transparent,
                    borderColor: _color,
                    borderWidth: 0,
                    borderStyle: BorderStyle.none,
                    textColor: Color.fromRGBO(0, 0, 0, 0.5),
                    onPress: () {
                      Navigator.push(
                          context, MaterialPageRoute(builder: (context) {
                        return LoginPage();
                      }));
                    }
                  ),
                ),
                Container(
                  child: canShowSocial ? OrDivider() : null
                ),
                Container(
                    child: canShowSocial ? Row(
                      mainAxisAlignment: MainAxisAlignment.center,
                      children: <Widget>[
                        SocalIcon(
                          iconSrc: "assets/icons/facebook.svg",
                          press: () {}, key: Key("1"),
                        ),
                        SocalIcon(
                          iconSrc: "assets/icons/twitter.svg",
                          press: () {}, key: Key("2"),
                        ),
                        SocalIcon(
                          iconSrc: "assets/icons/google-plus.svg",
                          press: () {}, key: Key("3"),
                        ),
                      ],
                    ) : null
                )
              ],
            )
        )
    );
  }
}

class OrDivider extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    return Container(
      margin: EdgeInsets.symmetric(vertical: size.height * 0.02),
      width: size.width * 0.8,
      child: Row(
        children: <Widget>[
          buildDivider(),
          Padding(
            padding: const EdgeInsets.symmetric(horizontal: 10),
            child: Text(
              "OR",
              style: TextStyle(
                color: mainColor,
                fontWeight: FontWeight.w600,
              ),
            ),
          ),
          buildDivider(),
        ],
      ),
    );
  }

  Expanded buildDivider() {
    return Expanded(
      child: Divider(
        color: Color(0xFFD9D9D9),
        height: 1.5,
      ),
    );
  }
}

class SocalIcon extends StatelessWidget {
  final String iconSrc;
  final Function press;
  const SocalIcon({
    required Key key,
    required this.iconSrc,
    required this.press,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      child: Container(
        margin: EdgeInsets.symmetric(horizontal: 10),
        padding: EdgeInsets.all(20),
        decoration: BoxDecoration(
          border: Border.all(
            width: 2,
            color: mainColor,
          ),
          shape: BoxShape.circle,
        ),
        child: SvgPicture.asset(
          iconSrc,
          height: 20,
          width: 20,
          color: mainColor,
        ),
      ),
    );
  }
}

==> kameleoon_client_flutter-2.0.2.tar.gz: example/lib/Pages/Signup/signup_page.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:kameleoon_client_flutter/kameleoon_client_flutter.dart';
import 'package:kameleoon_client_flutter_example/Components/Button.dart';
import 'package:kameleoon_client_flutter_example/Pages/Login/login_page.dart';
import 'package:flutter_svg/flutter_svg.dart';

import '../../constants.dart';
import 'package:kameleoon_client_flutter_example/Components/KTextInput.dart';

class SignupPage extends StatefulWidget {
  @override
  _SignupPage createState() => _SignupPage();
}

class _SignupPage extends State<SignupPage> {
  bool canShowSocial = false;
  Color _color = Color.fromRGBO(100, 100, 255, 1);

  @override
  void initState() {
    super.initState();
    initKameleoon();
  }

  Future<void> initKameleoon() async {
    KameleoonClient client = KameleoonClientFactory.create("yjiu8jw554");

    client.runWhenReady(() async {
      String visitorCode = await client.getVisitorCode();
      try {
        bool? ff = await client.isFeatureActive(visitorCode, "color-feature-flag");
        if (ff == true) {
          String? color = await client.getFeatureVariable(visitorCode, "color-feature-flag", "color") as String?;
          color = "FF" + color!.toUpperCase().replaceAll("#", "");
          mainColor = Color(int.parse(color, radix: 16));
          setState(() {
            _color = mainColor;
          });
        }
      } on FeatureNotFound {
      } on NotTargeted {
      } on PlatformException {
      }

      try {
        await client.addData(visitorCode, [CustomData(30, "9876543210"), CustomData(29, "asdasda")]);
        bool showSocial = await client.isFeatureActive(visitorCode, "show-social");
        setState(() {
          canShowSocial = showSocial;
        });
      } on FeatureNotFound {
      } on NotTargeted {
        print("Not targeted");
      }
    }, () {}, Duration(seconds: 5));
  }

  @override
  Widget build(BuildContext context) {
    Size screenSize = MediaQuery.of(context).size;
    return Scaffold(
        body: Container(
            width: screenSize.width,
            height: screenSize.height,
            child: Column(
              children: <Widget>[
                Padding(
                    padding: EdgeInsets.only(bottom: 20, top: 70),
                    child: Image.asset(
                      "assets/images/logo.png",
                    )
                ),
                Text(
                  "Welcome!",
                  style: TextStyle(
                    fontWeight: FontWeight.bold,
                    fontSize: 24,
                  ),
                ),
                Padding(
                    padding: EdgeInsets.only(top: 10, bottom: 50),
                    child: Text(
                        "Sign up to create your account",
                        style: TextStyle(
                            fontWeight: FontWeight.w400,
                            fontSize: 17
                        )
                    )
                ),
                Text(
                    "Username or e-mail address",
                    textAlign: TextAlign.left,
                    style: TextStyle(
                        fontWeight: FontWeight.bold,
                        fontSize: 14
                    )
                ),
                Padding(
                    padding: EdgeInsets.only(bottom: 20, top: 5),
                    child: KTextInput(
                        suffixIcon: false,
                        icon: Icons.person,
                        hint: "Username or Email"
                    )
                ),
                Text(
                    "Password",
                    textAlign: TextAlign.left,
                    style: TextStyle(
                        fontWeight: FontWeight.bold,
                        fontSize: 14
                    )
                ),
                Padding(
                    padding: EdgeInsets.only(bottom: 30, top: 5),
                    child: KTextInput(
                        suffixIcon: true,
                        icon: Icons.lock,
                        hint: "Password"
                    )
                ),
                Button(
                  text: "Sign up",
                  bgColor: _color,
                  borderColor: _color,
                  borderWidth: 0,
                  borderStyle: BorderStyle.none,
                  textColor: Colors.white,
                ),
                Padding(
                  padding: EdgeInsets.only(top: 5),
                  child: Button(
                    text: "Already have an Account? Sign in",
                    bgColor: Colors.transparent,
                    borderColor: _color,
                    borderWidth: 0,
                    borderStyle: BorderStyle.none,
                    textColor: Color.fromRGBO(0, 0, 0, 0.5),
                    onPress: () {
                      Navigator.push(
                          context, MaterialPageRoute(builder: (context) {
                        return LoginPage();
                      }));
                    }
                  ),
                ),
                Container(
                  child: canShowSocial ? OrDivider() : null
                ),
                Container(
                    child: canShowSocial ? Row(
                      mainAxisAlignment: MainAxisAlignment.center,
                      children: <Widget>[
                        SocalIcon(
                          iconSrc: "assets/icons/facebook.svg",
                          press: () {}, key: Key("1"),
                        ),
                        SocalIcon(
                          iconSrc: "assets/icons/twitter.svg",
                          press: () {}, key: Key("2"),
                        ),
                        SocalIcon(
                          iconSrc: "assets/icons/google-plus.svg",
                          press: () {}, key: Key("3"),
                        ),
                      ],
                    ) : null
                )
              ],
            )
        )
    );
  }
}

class OrDivider extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    return Container(
      margin: EdgeInsets.symmetric(vertical: size.height * 0.02),
      width: size.width * 0.8,
      child: Row(
        children: <Widget>[
          buildDivider(),
          Padding(
            padding: const EdgeInsets.symmetric(horizontal: 10),
            child: Text(
              "OR",
              style: TextStyle(
                color: mainColor,
                fontWeight: FontWeight.w600,
              ),
            ),
          ),
          buildDivider(),
        ],
      ),
    );
  }

  Expanded buildDivider() {
    return Expanded(
      child: Divider(
        color: Color(0xFFD9D9D9),
        height: 1.5,
      ),
    );
  }
}

class SocalIcon extends StatelessWidget {
  final String iconSrc;
  final Function press;
  const SocalIcon({
    required Key key,
    required this.iconSrc,
    required this.press,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      child: Container(
        margin: EdgeInsets.symmetric(horizontal: 10),
        padding: EdgeInsets.all(20),
        decoration: BoxDecoration(
          border: Border.all(
            width: 2,
            color: mainColor,
          ),
          shape: BoxShape.circle,
        ),
        child: SvgPicture.asset(
          iconSrc,
          height: 20,
          width: 20,
          color: mainColor,
        ),
      ),
    );
  }
}
